summaryrefslogtreecommitdiff
path: root/include/asterisk
diff options
context:
space:
mode:
authorRussell Bryant <russell@russellbryant.com>2008-03-04 22:15:18 +0000
committerRussell Bryant <russell@russellbryant.com>2008-03-04 22:15:18 +0000
commitefb1e30a387ae8ec3c92cc094bca542579007639 (patch)
treec68fb7815e708808b7831a1d5e05682f93f9c5f3 /include/asterisk
parent7b1e335999eac4754e9be43953dbd67fc11ff07a (diff)
Rename public object server_instance to ast_tcptls_server_instance
git-svn-id: https://origsvn.digium.com/svn/asterisk/trunk@105773 65c4cc65-6c06-0410-ace0-fbb531ad65f3
Diffstat (limited to 'include/asterisk')
-rw-r--r--include/asterisk/http.h2
-rw-r--r--include/asterisk/tcptls.h12
2 files changed, 7 insertions, 7 deletions
diff --git a/include/asterisk/http.h b/include/asterisk/http.h
index 4cda5cacc..320d5bc23 100644
--- a/include/asterisk/http.h
+++ b/include/asterisk/http.h
@@ -65,7 +65,7 @@
content is specified)
\endverbatim
*/
-typedef struct ast_str *(*ast_http_callback)(struct server_instance *ser, const char *uri, struct ast_variable *params, int *status, char **title, int *contentlength);
+typedef struct ast_str *(*ast_http_callback)(struct ast_tcptls_server_instance *ser, const char *uri, struct ast_variable *params, int *status, char **title, int *contentlength);
/*! \brief Definition of a URI reachable in the embedded HTTP server */
struct ast_http_uri {
diff --git a/include/asterisk/tcptls.h b/include/asterisk/tcptls.h
index 6b8260c5d..348e78082 100644
--- a/include/asterisk/tcptls.h
+++ b/include/asterisk/tcptls.h
@@ -102,7 +102,7 @@ struct ast_tls_config {
* or equivalent with a timeout of 'poll_timeout' milliseconds, and if the
* following accept() is successful it creates a thread in charge of
* running the session, whose body is desc->worker_fn(). The argument of
* worker_fn() is a struct server_instance, which contains the address
* of the other party, a pointer to desc, the file descriptors (fd) on which
* we can do a select/poll (but NOT IO/, and a FILE *on which we can do I/O.
* We have both because we want to support plain and SSL sockets, and
@@ -111,7 +111,7 @@ struct ast_tls_config {
*
* NOTE: in order to let other parts of asterisk use these services,
* we need to do the following:
* + move struct server_instance and struct server_args to
* a common header file, together with prototypes for
* server_start() and server_root().
*/
@@ -119,7 +119,7 @@ struct ast_tls_config {
/*! \brief
* describes a server instance
*/
-struct server_instance {
+struct ast_tcptls_server_instance {
FILE *f; /* fopen/funopen result */
int fd; /* the socket returned by accept() */
SSL *ssl; /* ssl state */
@@ -154,7 +154,7 @@ struct server_args {
#define LEN_T size_t
#endif
-struct server_instance *client_start(struct server_args *desc);
+struct ast_tcptls_server_instance *client_start(struct server_args *desc);
void *server_root(void *);
void server_start(struct server_args *desc);
@@ -163,7 +163,7 @@ int ssl_setup(struct ast_tls_config *cfg);
void *ast_make_file_from_fd(void *data);
-HOOK_T server_read(struct server_instance *ser, void *buf, size_t count);
-HOOK_T server_write(struct server_instance *ser, void *buf, size_t count);
+HOOK_T server_read(struct ast_tcptls_server_instance *ser, void *buf, size_t count);
+HOOK_T server_write(struct ast_tcptls_server_instance *ser, void *buf, size_t count);
#endif /* _ASTERISK_SERVER_H */
@@ -102,7 +102,7 @@ struct ast_tls_config {
* following accept() is successful it creates a thread in charge of
* running the session, whose body is desc->worker_fn(). The argument of
- * worker_fn() is a struct server_instance, which contains the address
+ * worker_fn() is a struct ast_tcptls_server_instance, which contains the address
* of the other party, a pointer to desc, the file descriptors (fd) on which
* we can do a select/poll (but NOT IO/, and a FILE *on which we can do I/O.
@@ -111,7 +111,7 @@ struct ast_tls_config {
* NOTE: in order to let other parts of asterisk use these services,
* we need to do the following:
- * + move struct server_instance and struct server_args to
+ * + move struct ast_tcptls_server_instance and struct server_args to
* a common header file, together with prototypes for
* server_start() and server_root().